Function diem_json_rpc::data::get_network_status [−][src]
pub fn get_network_status(_role: &str) -> Result<u64, JsonRpcError>Expand description
Returns the number of peers this node is connected to
pub fn get_network_status(_role: &str) -> Result<u64, JsonRpcError>Returns the number of peers this node is connected to